-- On linux, run psql -d actionHubDb -f Upgrade.sql
DO
$do$
BEGIN


-- 1. delete liquibase tables which are no longer needed, also delete sequences that are not used if the databasechangelock / log tables were created during 16.7 or 16.10
IF EXISTS (SELECT relname from pg_class where relname='databasechangeloglock') THEN
BEGIN
   raise notice 'deleting databasechangeloglock table';
   DROP TABLE databasechangeloglock;
END;
END IF;


IF EXISTS (SELECT relname from pg_class where relname='databasechangelog') THEN
BEGIN
   raise notice 'deleting databasechangelog table';
   DROP TABLE databasechangelog;
   raise notice 'dropping duplicate sequences created from initial liquibase file';
   DROP SEQUENCE IF EXISTS amqp_connection_id_seq;
   DROP SEQUENCE IF EXISTS audit_change_id_seq;
   DROP SEQUENCE IF EXISTS audit_entry_id_seq;
   DROP SEQUENCE IF EXISTS propertyvalue_id_seq;
   DROP SEQUENCE IF EXISTS registrysetting_id_seq;
   DROP SEQUENCE IF EXISTS rule_argument_id_seq;
   DROP SEQUENCE IF EXISTS rule_execution_history_id_seq;
   DROP SEQUENCE IF EXISTS rule_id_seq;
   DROP SEQUENCE IF EXISTS rule_scope_id_seq;
   DROP SEQUENCE IF EXISTS schema_versions_id_seq;
   raise notice 'renaming sequences for consistency';
   ALTER SEQUENCE IF EXISTS amqp_connection_id_seq1 RENAME TO amqp_connection_id_seq;
   ALTER SEQUENCE IF EXISTS audit_change_id_seq1 RENAME TO audit_change_id_seq;
   ALTER SEQUENCE IF EXISTS audit_entry_id_seq1 RENAME TO audit_entry_id_seq;
   ALTER SEQUENCE IF EXISTS propertyvalue_id_seq1 RENAME TO propertyvalue_id_seq;
   ALTER SEQUENCE IF EXISTS registrysetting_id_seq1 RENAME TO registrysetting_id_seq;
   ALTER SEQUENCE IF EXISTS rule_argument_id_seq1 RENAME TO rule_argument_id_seq;
   ALTER SEQUENCE IF EXISTS rule_execution_history_id_seq1 RENAME TO rule_execution_history_id_seq;
   ALTER SEQUENCE IF EXISTS rule_id_seq1 RENAME TO rule_id_seq;
   ALTER SEQUENCE IF EXISTS rule_scope_id_seq1 RENAME TO rule_scope_id_seq;
   ALTER SEQUENCE IF EXISTS schema_versions_id_seq1 RENAME TO schema_versions_id_seq;
END;
END IF;

-- 2. create new tables
IF NOT EXISTS (SELECT relname from pg_class where relname='daemon') THEN
BEGIN
raise notice 'creating daemon table';
CREATE TABLE daemon (
    id bigint NOT NULL,
    host_name character varying(255) NOT NULL,
    last_checkin timestamp without time zone NOT NULL,
    port bigint NOT NULL
);


--
-- Name: daemon_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE daemon_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: daemon_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE daemon_id_seq OWNED BY daemon.id;

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY daemon ALTER COLUMN id SET DEFAULT nextval('daemon_id_seq'::regclass);

--
-- Name: daemon_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY daemon
    ADD CONSTRAINT daemon_pkey PRIMARY KEY (id);

ALTER TABLE daemon OWNER to "actionHub"; 

END;
END IF;

IF NOT EXISTS (SELECT relname from pg_class where relname='workflow_system') THEN
BEGIN
raise notice 'creating workflow_system table';
--
-- Name: workflow_system; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE workflow_system (
    id bigint NOT NULL,
    last_checkin timestamp without time zone,
    name character varying(255) NOT NULL,
    plug_id character varying(255) NOT NULL
);


--
-- Name: workflow_system_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE workflow_system_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: workflow_system_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE workflow_system_id_seq OWNED BY workflow_system.id;

ALTER TABLE ONLY workflow_system ALTER COLUMN id SET DEFAULT nextval('workflow_system_id_seq'::regclass);

--
-- Name: workflow_system_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--
ALTER TABLE ONLY workflow_system
    ADD CONSTRAINT workflow_system_pkey PRIMARY KEY (id);

ALTER TABLE workflow_system OWNER to "actionHub"; 

END;
END IF;

IF NOT EXISTS (SELECT relname from pg_class where relname='rule_match_history') THEN
BEGIN
raise notice 'creating rule_match_history table';
CREATE TABLE rule_match_history (
  id bigint NOT NULL,
  match_time timestamp without time zone NOT NULL,
  rule_id bigint,
  CONSTRAINT fk_2yljrm5hc7jabam05t2yf5pdu FOREIGN KEY (rule_id)
	  REFERENCES public.rule (id) MATCH SIMPLE
	  ON UPDATE NO ACTION ON DELETE NO ACTION
);


--
-- Name: rule_match_history_id_seq; Type: SEQUENCE; Schema: public; Owner: -
--

CREATE SEQUENCE rule_match_history_id_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


--
-- Name: rule_match_history_id_seq; Type: SEQUENCE OWNED BY; Schema: public; Owner: -
--

ALTER SEQUENCE rule_match_history_id_seq OWNED BY rule_match_history.id;

--
-- Name: id; Type: DEFAULT; Schema: public; Owner: -
--

ALTER TABLE ONLY rule_match_history ALTER COLUMN id SET DEFAULT nextval('rule_match_history_id_seq'::regclass);

--
-- Name: rule_match_history_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY rule_match_history
    ADD CONSTRAINT rule_match_history_pkey PRIMARY KEY (id);

ALTER TABLE rule_match_history OWNER to "actionHub"; 

END;
END IF;

-- 3. Add new constraints
--
-- Name: uk_2vkhdu82rcnviknukwiuxu7ah; Type: CONSTRAINT; Schema: public; Owner: -
--
IF NOT EXISTS (select * from pg_constraint where conname = 'uk_2vkhdu82rcnviknukwiuxu7ah')  THEN
BEGIN
    raise notice 'adding constraint for registry setting name uniqueness';
    ALTER TABLE ONLY registrysetting
        ADD CONSTRAINT uk_2vkhdu82rcnviknukwiuxu7ah UNIQUE (name);
END;
END IF;


-- 4. Add new columns

IF NOT EXISTS (SELECT column_name 
               FROM information_schema.columns 
               WHERE table_schema='public' and table_name='rule' and column_name='match_count_supported') THEN
BEGIN
ALTER TABLE rule ADD column match_count_supported boolean NOT NULL DEFAULT false, ADD column match_count bigint, ADD column match_duration_value bigint, ADD column match_duration_unit integer;
END;
END IF;

raise notice 'updating schema version';
-- 5. Update the schema version
UPDATE schema_versions set compat = '1701', version = '1701' 
where ID = 1;

raise notice 'upgrade schema completed';

END
$do$

